@@ -127,12 +127,6 @@ var PMA_console = {
             PMA_consoleDebug.initialize();
 
             PMA_console.$consoleToolbar.children('.console_switch').click(PMA_console.toggle);
-            $(document).keydown(function(event) {
-                // Ctrl + Alt + C
-                if (event.ctrlKey && event.altKey && event.keyCode === 67) {
-                    PMA_console.toggle();
-                }
-            });
 
             $('#pma_console').find('.toolbar').children().mousedown(function(event) {
                 event.preventDefault();
@@ -195,16 +189,15 @@ var PMA_console = {
                 if (ajaxOptions.dataType && ajaxOptions.dataType.indexOf('json') != -1) {
                     return;
                 }
+                if (xhr.status !== 200) {
+                    return;
+                }
                 try {
-                    var data = $.parseJSON(xhr.responseText);
+                    var data = JSON.parse(xhr.responseText);
                     PMA_console.ajaxCallback(data);
                 } catch (e) {
-                    console.log("Invalid JSON!" + e.message);
-                    if (AJAX.xhr && AJAX.xhr.status === 0 && AJAX.xhr.statusText !== 'abort') {
-                        PMA_ajaxShowMessage($('<div />',{'class':'error','html':PMA_messages.strRequestFailed+' ( '+escapeHtml(AJAX.xhr.statusText)+' )'}));
-                        AJAX.active = false;
-                        AJAX.xhr = null;
-                    }
+                    console.trace();
+                    console.log("Failed to parse JSON: " + e.message);
                 }
             });
 
@@ -255,7 +248,7 @@ var PMA_console = {
         if (options && options.profiling === true) {
             PMA_console.$requestForm.append('<input name="profiling" value="on">');
         }
-        if (! confirmQuery(PMA_console.$requestForm[0], PMA_console.$requestForm.children('textarea')[0])) {
+        if (! confirmQuery(PMA_console.$requestForm[0], PMA_console.$requestForm.children('textarea')[0].value)) {
             return;
         }
         PMA_console.$requestForm.children('[name=console_message_id]')
