@@ -402,7 +402,12 @@ RTE.COMMON = {
              *          the AJAX message shown to the user
              */
             var $msg = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
-            $.post(url, {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+            var params = {
+                'is_js_confirmed': 1,
+                'ajax_request': true,
+                'token': PMA_commonParams.get('token')
+            };
+            $.post(url, params, function (data) {
                 if (data.success === true) {
                     /**
                      * @var $table Object containing reference
@@ -476,7 +481,12 @@ RTE.COMMON = {
                  * @var $curr_row Object containing reference to the current row
                  */
                 var $curr_row = $anchor.parents('tr');
-                $.post($anchor.attr('href'), {'is_js_confirmed': 1, 'ajax_request': true}, function (data) {
+                var params = {
+                    'is_js_confirmed': 1,
+                    'ajax_request': true,
+                    'token': PMA_commonParams.get('token')
+                };
+                $.post($anchor.attr('href'), params, function (data) {
                     returnCount++;
                     if (data.success === true) {
                         /**
@@ -792,8 +802,6 @@ RTE.ROUTINE = {
         // Process for parameter length
         switch ($type.val()) {
         case 'DATE':
-        case 'DATETIME':
-        case 'TIME':
         case 'TINYBLOB':
         case 'TINYTEXT':
         case 'BLOB':
@@ -824,7 +832,11 @@ RTE.ROUTINE = {
          *          the AJAX message shown to the user
          */
         var $msg = PMA_ajaxShowMessage();
-        $.post($this.attr('href'), {'ajax_request': true}, function (data) {
+        var params = {
+            'ajax_request': true,
+            'token': PMA_commonParams.get('token')
+        };
+        $.post($this.attr('href'), params, function (data) {
             if (data.success === true) {
                 PMA_ajaxRemoveMessage($msg);
                 // If 'data.dialog' is true we show a dialog with a form
