@@ -50,7 +50,7 @@ AJAX.registerOnload('server_variables.js', function () {
 
     /* Filters the rows by the user given regexp */
     function filterVariables(textFilter) {
-        var mark_next = false, $row, odd_row = false;
+        var mark_next = false, $row;
         $('#serverVariables').find('.var-row').not('.var-header').each(function () {
             $row = $(this);
             if (mark_next || textFilter === null ||
@@ -59,14 +59,7 @@ AJAX.registerOnload('server_variables.js', function () {
                 // If current global value is different from session value
                 // (has class diffSession), then display that one too
                 mark_next = $row.hasClass('diffSession') && ! mark_next;
-
-                odd_row = ! odd_row;
                 $row.css('display', '');
-                if (odd_row) {
-                    $row.addClass('odd').removeClass('even');
-                } else {
-                    $row.addClass('even').removeClass('odd');
-                }
             } else {
                 $row.css('display', 'none');
             }
@@ -93,7 +86,8 @@ AJAX.registerOnload('server_variables.js', function () {
                     ajax_request: true,
                     type: 'setval',
                     varName: varName,
-                    varValue: $valueCell.find('input').val()
+                    varValue: $valueCell.find('input').val(),
+                    token: PMA_commonParams.get('token')
                 }, function (data) {
                     if (data.success) {
                         $valueCell
