@@ -1562,7 +1562,7 @@ class DbQbe
         if (empty($from_clause)) {
             // Create cartesian product
             $from_clause = implode(
-                ", ", array_map(array('Util', 'backquote'), $search_tables)
+                ", ", array_map(array('PMA\libraries\Util', 'backquote'), $search_tables)
             );
         }
 
@@ -1668,7 +1668,7 @@ class DbQbe
             if (count($unfinalized) > 0) {
                 // Add these tables as cartesian product before joined tables
                 $join .= implode(
-                    ', ', array_map(array('Util', 'backquote'), $unfinalized)
+                    ', ', array_map(array('PMA\libraries\Util', 'backquote'), $unfinalized)
                 );
             }
         }
