@@ -8,6 +8,8 @@
  */
 namespace PMA\libraries;
 
+use PMA\libraries\URL;
+
 /**
  * This class provides data about the server status
  *
@@ -142,13 +144,13 @@ class ServerStatusData
         // variable or section name => (name => url)
 
         $links['table'][__('Flush (close) all tables')] = $this->selfUrl
-            . PMA_URL_getCommon(
+            . URL::getCommon(
                 array(
                     'flush' => 'TABLES'
                 )
             );
         $links['table'][__('Show open tables')]
-            = 'sql.php' . PMA_URL_getCommon(
+            = 'sql.php' . URL::getCommon(
                 array(
                     'sql_query' => 'SHOW OPEN TABLES',
                     'goto' => $this->selfUrl,
@@ -157,7 +159,7 @@ class ServerStatusData
 
         if ($GLOBALS['replication_info']['master']['status']) {
             $links['repl'][__('Show slave hosts')]
-                = 'sql.php' . PMA_URL_getCommon(
+                = 'sql.php' . URL::getCommon(
                     array(
                         'sql_query' => 'SHOW SLAVE HOSTS',
                         'goto' => $this->selfUrl,
@@ -173,7 +175,7 @@ class ServerStatusData
 
         $links['qcache'][__('Flush query cache')]
             = $this->selfUrl
-            . PMA_URL_getCommon(
+            . URL::getCommon(
                 array(
                     'flush' => 'QUERY CACHE'
                 )
@@ -189,11 +191,10 @@ class ServerStatusData
         $links['Slow_queries']['doc'] = 'slow_query_log';
 
         $links['innodb'][__('Variables')]
-            = 'server_engines.php?engine=InnoDB&amp;'
-            . PMA_URL_getCommon(array(), 'html', '');
+            = 'server_engines.php?' . URL::getCommon(array('engine' => 'InnoDB'));
         $links['innodb'][__('InnoDB Status')]
             = 'server_engines.php'
-            . PMA_URL_getCommon(
+            . URL::getCommon(
                 array(
                     'engine' => 'InnoDB',
                     'page' => 'Status'
@@ -418,7 +419,7 @@ class ServerStatusData
      */
     public function getMenuHtml()
     {
-        $url_params = PMA_URL_getCommon();
+        $url_params = URL::getCommon();
         $items = array(
             array(
                 'name' => __('Server'),
