@@ -5,16 +5,19 @@
  *
  * @package PhpMyAdmin
  */
+use PMA\libraries\config\PageSettings;
+use PMA\libraries\Response;
 
 /**
  *
  */
 require_once 'libraries/common.inc.php';
-require_once 'libraries/config/page_settings.class.php';
+require_once 'libraries/config/user_preferences.forms.php';
+require_once 'libraries/config/page_settings.forms.php';
 
-PMA_PageSettings::showGroup('Import');
+PageSettings::showGroup('Import');
 
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('import.js');
@@ -28,7 +31,6 @@ $url_query .= '&amp;goto=tbl_import.php&amp;back=tbl_import.php';
 require_once 'libraries/tbl_info.inc.php';
 
 require 'libraries/display_import.lib.php';
-$response = PMA_Response::getInstance();
 $response->addHTML(
     PMA_getImportDisplay(
         'table', $db, $table, $max_upload_size
